@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # flake8: noqa
 # Copyright (C) 2013, the codeeditor development team
 #
@@ -68,7 +67,7 @@ class CodeEditor(
     ScrollWithUpDownKeys,
     HomeKey,
     EndKey,
-    NumpadPeriodKey,
+    # NumpadPeriodKey,  -> disabled, see issue #720
     AutoIndent,
     PythonAutoIndent,
     AutoCloseQuotesAndBrackets,
