@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
 # Pyzo is distributed under the terms of the 2-Clause BSD License.
@@ -25,13 +24,9 @@ from pyzo.core.pyzoLogging import print
 from pyzo.core.icons import EditorTabToolButton
 from pyzo import translate
 
-# Constants for the alignments of tabs
-MIN_NAME_WIDTH = 50
-MAX_NAME_WIDTH = 200
-
 
 def simpleDialog(item, action, question, options, defaultOption):
-    """simpleDialog(editor, action, question, options, defaultOption)
+    """builds and displays a simple dialog
 
     Options with special buttons
     ----------------------------
@@ -39,7 +34,6 @@ def simpleDialog(item, action, question, options, defaultOption):
     help, saveall, yes, yestoall, no, notoall, abort, retry, ignore.
 
     Returns the selected option as a string, or None if canceled.
-
     """
 
     # Get filename
@@ -49,26 +43,26 @@ def simpleDialog(item, action, question, options, defaultOption):
         filename = item.id()
 
     # create button map
-    mb = QtWidgets.QMessageBox
+    SB = QtWidgets.QMessageBox.StandardButton
     M = {
-        "ok": mb.Ok,
-        "open": mb.Open,
-        "save": mb.Save,
-        "cancel": mb.Cancel,
-        "close": mb.Close,
-        "discard": mb.Discard,
-        "apply": mb.Apply,
-        "reset": mb.Reset,
-        "restoredefaults": mb.RestoreDefaults,
-        "help": mb.Help,
-        "saveall": mb.SaveAll,
-        "yes": mb.Yes,
-        "yestoall": mb.YesToAll,
-        "no": mb.No,
-        "notoall": mb.NoToAll,
-        "abort": mb.Abort,
-        "retry": mb.Retry,
-        "ignore": mb.Ignore,
+        "ok": SB.Ok,
+        "open": SB.Open,
+        "save": SB.Save,
+        "cancel": SB.Cancel,
+        "close": SB.Close,
+        "discard": SB.Discard,
+        "apply": SB.Apply,
+        "reset": SB.Reset,
+        "restoredefaults": SB.RestoreDefaults,
+        "help": SB.Help,
+        "saveall": SB.SaveAll,
+        "yes": SB.Yes,
+        "yestoall": SB.YesToAll,
+        "no": SB.No,
+        "notoall": SB.NoToAll,
+        "abort": SB.Abort,
+        "retry": SB.Retry,
+        "ignore": SB.Ignore,
     }
 
     # setup dialog
@@ -85,19 +79,16 @@ def simpleDialog(item, action, question, options, defaultOption):
         if option_lower in M:
             button = dlg.addButton(M[option_lower])
         else:
-            button = dlg.addButton(option, dlg.AcceptRole)
+            button = dlg.addButton(option, dlg.ButtonRole.AcceptRole)
         buttons[button] = option
         # Set as default?
         if option_lower == defaultOption.lower():
             dlg.setDefaultButton(button)
 
     # get result
-    dlg.exec_()
+    dlg.exec()
     button = dlg.clickedButton()
-    if button in buttons:
-        return buttons[button]
-    else:
-        return None
+    return buttons.get(button, None)
 
 
 def get_shortest_unique_filename(filename, filenames):
@@ -137,7 +128,7 @@ def get_shortest_unique_filename(filename, filenames):
 
     # Produce display name based on base name and last most-unique part
     displayname = nameparts1[-1]
-    for i in reversed(range(len(uniqueness) - 1)):
+    for i in range(len(uniqueness) - 1)[::-1]:
         displayname = "/" + displayname
         if uniqueness[i] == max_uniqueness:
             displayname = nameparts1[i] + displayname
@@ -168,8 +159,7 @@ class FileItem:
 
     @property
     def id(self):
-        """Get an id of this editor. This is the filename,
-        or for tmp files, the name."""
+        """Get an id of this editor. This is the filename, or for tmp files, the name."""
         if self.filename:
             return self.filename
         else:
@@ -203,9 +193,9 @@ class FindReplaceWidget(QtWidgets.QFrame):
     """A widget to find and replace text."""
 
     def __init__(self, *args):
-        QtWidgets.QFrame.__init__(self, *args)
+        super().__init__(*args)
 
-        self.setFocusPolicy(QtCore.Qt.ClickFocus)
+        self.setFocusPolicy(QtCore.Qt.FocusPolicy.ClickFocus)
 
         # init layout
         layout = QtWidgets.QHBoxLayout(self)
@@ -361,7 +351,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
             self._wholeWord,
             self._regExp,
         ]:
-            # but.setFocusPolicy(QtCore.Qt.ClickFocus)
+            # but.setFocusPolicy(QtCore.Qt.FocusPolicy.ClickFocus)
             but.clicked.connect(self.autoHideTimerReset)
 
         # create timer objects
@@ -392,7 +382,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         self._autoHide.setChecked(bool(pyzo.config.state.find_autoHide))
 
         # show or hide?
-        if bool(pyzo.config.state.find_show):
+        if pyzo.config.state.find_show:
             self.show()
         else:
             self.hide()
@@ -404,7 +394,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         """Check whether we should hide the tool."""
         timeout = pyzo.config.advanced.find_autoHide_timeout
         if self._autoHide.isChecked():
-            if (time.time() - self._timerAutoHide_t0) > timeout:  # seconds
+            if time.time() - self._timerAutoHide_t0 > timeout:  # seconds
                 # Hide if editor has focus
                 self._replaceKind.setCurrentIndex(0)  # set replace to "one"
                 es = self.parent()  # editor stack
@@ -427,15 +417,15 @@ class FindReplaceWidget(QtWidgets.QFrame):
         overload event instead of KeyPressEvent.
         """
         if isinstance(event, QtGui.QKeyEvent):
-            if event.key() in (QtCore.Qt.Key_Tab, QtCore.Qt.Key_Backtab):
+            if event.key() in (QtCore.Qt.Key.Key_Tab, QtCore.Qt.Key.Key_Backtab):
                 event.accept()  # focusNextPrevChild is called by Qt
                 return True
-            elif event.key() == QtCore.Qt.Key_Escape:
+            elif event.key() == QtCore.Qt.Key.Key_Escape:
                 self.hideMe()
                 event.accept()
                 return True
         # Otherwise ... handle in default manner
-        return QtWidgets.QFrame.event(self, event)
+        return super().event(event)
 
     def handleReplacePossible(self, state):
         """Disable replacing when using regular expressions."""
@@ -468,8 +458,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         self.setStyleSheet("QFrame {}")
 
     def selectFindText(self):
-        """Select the textcontrol for the find needle,
-        and the text in it"""
+        """Select the textcontrol for the find needle, and the text in it"""
         # select text
         self._findText.selectAll()
         # focus
@@ -492,8 +481,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         self.findPrevious()
 
     def find(self, forward=True, wrapAround=True, editor=None):
-        """The main find method.
-        Returns True if a match was found."""
+        """The main find method. Returns True if a match was found."""
 
         # Reset timer
         self.autoHideTimerReset()
@@ -505,13 +493,13 @@ class FindReplaceWidget(QtWidgets.QFrame):
                 return
 
         # find flags
-        flags = QtGui.QTextDocument.FindFlags()
+        flags = QtGui.QTextDocument.FindFlag(0)
         if self._caseCheck.isChecked():
-            flags |= QtGui.QTextDocument.FindCaseSensitively
+            flags |= QtGui.QTextDocument.FindFlag.FindCaseSensitively
         if not forward:
-            flags |= QtGui.QTextDocument.FindBackward
+            flags |= QtGui.QTextDocument.FindFlag.FindBackward
         # if self._wholeWord.isChecked():
-        #    flags |= QtGui.QTextDocument.FindWholeWords
+        #    flags |= QtGui.QTextDocument.FindFlag.FindWholeWords
 
         # focus
         self.selectFindText()
@@ -519,18 +507,19 @@ class FindReplaceWidget(QtWidgets.QFrame):
         # get text to find
         needle = self._findText.text()
 
-        PatternOption = QtCore.QRegularExpression.PatternOption
+        QRE = QtCore.QRegularExpression
+        PatternOption = QRE.PatternOption
         regexFlags = PatternOption.NoPatternOption
         if not self._caseCheck.isChecked():
             regexFlags |= PatternOption.CaseInsensitiveOption
 
         if self._regExp.isChecked():
-            needle = QtCore.QRegularExpression(needle, regexFlags)
+            needle = QRE(needle, regexFlags)
         elif self._wholeWord.isChecked():
-            # Use regexp, because the default begaviour does not find
+            # Use regexp, because the default behaviour does not find
             # whole words correctly, see issue #276
             # it should *not* find this in this_word
-            needle = QtCore.QRegularExpression(r"\b" + needle + r"\b", regexFlags)
+            needle = QRE(r"\b" + QRE.escape(needle) + r"\b", regexFlags)
 
         # establish start position
         cursor = editor.textCursor()
@@ -542,9 +531,9 @@ class FindReplaceWidget(QtWidgets.QFrame):
             self.notifyPassBeginEnd()
             # Move cursor to start or end of document
             if forward:
-                cursor.movePosition(cursor.Start)
+                cursor.movePosition(cursor.MoveOperation.Start)
             else:
-                cursor.movePosition(cursor.End)
+                cursor.movePosition(cursor.MoveOperation.End)
             # Try again
             result = editor.document().find(needle, cursor, flags)
             if not result.isNull():
@@ -563,7 +552,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         elif i == 2:
             self.replaceInAllFiles(event)
         else:
-            raise RuntimeError("Unexpected kind of replace %s" % i)
+            raise RuntimeError("Unexpected kind of replace {}".format(i))
 
     def replaceOne(self, event=None, wrapAround=True, editor=None):
         """If the currently selected text matches the find string,
@@ -624,7 +613,7 @@ class FindReplaceWidget(QtWidgets.QFrame):
         cursor = editor.textCursor()
         cursor.beginEditBlock()
         try:
-            cursor.movePosition(cursor.Start)
+            cursor.movePosition(cursor.MoveOperation.Start)
             editor.setTextCursor(cursor)
             while self.replaceOne(wrapAround=False, editor=editor):
                 pass
@@ -650,7 +639,7 @@ class FileTabWidget(CompactTabWidget):
     fileTabsChanged = QtCore.Signal()
 
     def __init__(self, parent):
-        CompactTabWidget.__init__(self, parent, padding=(2, 1, 0, 4))
+        super().__init__(parent, padding=(2, 1, 0, 4))
 
         # Init main file
         self._mainFile = ""
@@ -673,7 +662,7 @@ class FileTabWidget(CompactTabWidget):
 
     def setTitleInMainWindowWhenTabChanged(self, index):
         # Valid index?
-        if index < 0 or index >= self.count():
+        if not (0 <= index < self.count()):
             pyzo.main.setMainTitle()  # No open file
 
         # Remove current item from history
@@ -691,9 +680,8 @@ class FileTabWidget(CompactTabWidget):
         items = []
         for i in range(tabBar.count()):
             item = tabBar.tabData(i)
-            if item is None:
-                continue
-            items.append(item)
+            if item is not None:
+                items.append(item)
         return items
 
     def currentItem(self):
@@ -706,25 +694,20 @@ class FileTabWidget(CompactTabWidget):
         return self.tabBar().tabData(i)
 
     def mainItem(self):
-        """Get the item corresponding to the "main" file. Returns None
-        if there is no main file.
+        """Get the item corresponding to the "main" file.
+
+        Returns None if there is no main file.
         """
         for item in self.items():
             if item.id == self._mainFile:
                 return item
-        else:
-            return None
+        return None
 
     def trackHistory(self, index):
-        """trackHistory(index)
-
-        Called when a tab is changed. Puts the current item on top of
-        the history.
-
-        """
+        """Called when a tab is changed. Puts the current item on top of the history."""
 
         # Valid index?
-        if index < 0 or index >= self.count():
+        if not (0 <= index < self.count()):
             return
 
         # Remove current item from history
@@ -739,11 +722,9 @@ class FileTabWidget(CompactTabWidget):
         self._itemHistory[10:] = []
 
     def setCurrentItem(self, item):
-        """_setCurrentItem(self, item)
-
-        Set a FileItem instance to be the current. If the given item
-        is not in the list, no action is taken.
+        """Set a FileItem instance to be the current.
 
+        If the given item is not in the list, no action is taken.
         item can be an int, FileItem, or file name.
         """
 
@@ -783,28 +764,19 @@ class FileTabWidget(CompactTabWidget):
     ## Closing, adding and updating
 
     def onClose(self):
-        """onClose()
-
-        Request to close the current tab.
-
-        """
+        """Request to close the current tab."""
 
         self.tabCloseRequested.emit(self.currentIndex())
 
     def removeTab(self, which):
-        """removeTab(which)
-
-        Removes the specified tab. which can be an integer, an item,
-        or an editor.
-
-        """
+        """Removes the specified tab. which can be an integer, an item, or an editor."""
 
         # Init
         items = self.items()
         theIndex = -1
 
         # Find index
-        if isinstance(which, int) and which >= 0 and which < len(items):
+        if isinstance(which, int) and 0 <= which < len(items):
             theIndex = which
 
         elif isinstance(which, FileItem):
@@ -832,7 +804,7 @@ class FileTabWidget(CompactTabWidget):
 
         if theIndex >= 0:
             # Close tab
-            CompactTabWidget.removeTab(self, theIndex)
+            super().removeTab(theIndex)
 
             # Delete editor
             items[theIndex].editor.destroy()
@@ -841,18 +813,15 @@ class FileTabWidget(CompactTabWidget):
             self.fileTabsChanged.emit()
 
     def addItem(self, item, update=True):
-        """addItem(item, update=True)
-
-        Add item to the tab widget. Set update to false if you are
+        """Add item to the tab widget. Set update to False if you are
         calling this method many times in a row. Then use updateItemsFull()
         to update the tab widget.
-
         """
 
         # Add tab and widget
         i = self.addTab(item.editor, item.name)
         tabBut = EditorTabToolButton(self.tabBar())
-        self.tabBar().setTabButton(i, QtWidgets.QTabBar.LeftSide, tabBut)
+        self.tabBar().setTabButton(i, QtWidgets.QTabBar.ButtonPosition.LeftSide, tabBut)
 
         # Keep informed about changes
         item.editor.somethingChanged.connect(self.updateItems)
@@ -871,21 +840,14 @@ class FileTabWidget(CompactTabWidget):
             self.updateItems()
 
     def updateItemsFull(self):
-        """updateItemsFull()
-
-        Update the appearance of the items and also updates names and
+        """Update the appearance of the items and also updates names and
         re-aligns the items.
-
         """
         self.updateItems()
         self.tabBar().alignTabs()
 
     def updateItems(self):
-        """updateItems()
-
-        Update the appearance of the items.
-
-        """
+        """Update the appearance of the items."""
 
         # Get items and tab bar
         items = self.items()
@@ -893,16 +855,12 @@ class FileTabWidget(CompactTabWidget):
 
         # Check whether we have name clashes, which we can try to resolve
         namecounts = {}
-        for i in range(len(items)):
-            item = items[i]
+        for i, item in enumerate(items):
             if item is None:
                 continue
-            xx = namecounts.setdefault(item.name, [])
-            xx.append(item)
+            namecounts.setdefault(item.name, []).append(item)
 
-        for i in range(len(items)):
-            # Get item
-            item = items[i]
+        for i, item in enumerate(items):
             if item is None:
                 continue
 
@@ -918,7 +876,7 @@ class FileTabWidget(CompactTabWidget):
                     )
                 except Exception as err:
                     # Catch this, just in case ...
-                    print("could not get unique name for:\n%r" % filenames)
+                    print("could not get unique name for:\n{!r}".format(filenames))
                     print(err)
                     display_name = item.name
 
@@ -932,11 +890,12 @@ class FileTabWidget(CompactTabWidget):
 
             # Determine text color. Is main file? Is current?
             if self._mainFile == item.id:
-                tabBar.setTabTextColor(i, QtGui.QColor("#008"))
+                color = "#0cf" if pyzo.darkQt else "#008"
             elif i == self.currentIndex():
-                tabBar.setTabTextColor(i, QtGui.QColor("#000"))
+                color = "#fff" if pyzo.darkQt else "#000"
             else:
-                tabBar.setTabTextColor(i, QtGui.QColor("#444"))
+                color = "#ddd" if pyzo.darkQt else "#444"
+            tabBar.setTabTextColor(i, QtGui.QColor(color))
 
             # Get number of blocks
             nBlocks = item.editor.blockCount()
@@ -944,7 +903,7 @@ class FileTabWidget(CompactTabWidget):
                 nBlocks = 0
 
             # Update appearance of icon
-            but = tabBar.tabButton(i, QtWidgets.QTabBar.LeftSide)
+            but = tabBar.tabButton(i, QtWidgets.QTabBar.ButtonPosition.LeftSide)
             but.updateIcon(item.dirty, self._mainFile == item.id, item.pinned, nBlocks)
 
         self.fileTabsChanged.emit()
@@ -965,7 +924,7 @@ class EditorTabs(QtWidgets.QWidget):
     parserDone = QtCore.Signal()
 
     def __init__(self, parent):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         # keep a booking of opened directories
         self._lastpath = ""
@@ -1005,9 +964,9 @@ class EditorTabs(QtWidgets.QWidget):
         # restore state (call later so that the menu module can bind to the
         # currentChanged signal first, in order to set tab/indentation
         # checkmarks appropriately)
-        # todo: Resetting the scrolling would work better if set after
-        # the widgets are properly sized.
-        pyzo.callLater(self.restoreEditorState)
+
+        # self.restoreEditorState should be called from outside after the paintNow call
+        # otherwise the horizontal scrollbar would be set for a too small widget size
 
     @property
     def _fileDialogOptions(self):
@@ -1022,7 +981,7 @@ class EditorTabs(QtWidgets.QWidget):
         from pyzo.core.menu import EditorTabContextMenu
 
         self._menu = EditorTabContextMenu(self, "EditorTabMenu")
-        self._tabs.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self._tabs.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         self._tabs.customContextMenuRequested.connect(self.contextMenuTriggered)
 
     def contextMenuTriggered(self, p):
@@ -1055,7 +1014,8 @@ class EditorTabs(QtWidgets.QWidget):
 
     def getMainEditor(self):
         """Get the editor that represents the main file, or None if
-        there is no main file."""
+        there is no main file.
+        """
         item = self._tabs.mainItem()
         if item:
             return item.editor
@@ -1112,7 +1072,7 @@ class EditorTabs(QtWidgets.QWidget):
                     active = (filename, linenr) == filename_linenr[-1]
                     editor.setDebugLineIndicator(linenr, active)
 
-    ## Loading ad saving files
+    ## Loading and saving files
 
     def dragEnterEvent(self, event):
         if event.mimeData().hasUrls():
@@ -1148,7 +1108,6 @@ class EditorTabs(QtWidgets.QWidget):
         """Create a dialog for the user to select a file."""
 
         # determine start dir
-        # todo: better selection of dir, using project manager
         editor = self.getCurrentEditor()
         if editor and editor._filename:
             startdir = os.path.split(editor._filename)[0]
@@ -1165,11 +1124,9 @@ class EditorTabs(QtWidgets.QWidget):
         # filter += "Py+Cy+C (*.py *.pyw *.pyi *.pyx *.pxd *.c *.h *.cpp);;"
         filter += "All (*)"
         if True:
-            filenames = QtWidgets.QFileDialog.getOpenFileNames(
+            filenames, selectedFilter = QtWidgets.QFileDialog.getOpenFileNames(
                 self, msg, startdir, filter, options=self._fileDialogOptions
             )
-            if isinstance(filenames, tuple):  # PySide
-                filenames = filenames[0]
         else:
             # Example how to preselect files, can be used when the users
             # opens a file in a project to select all files currently not
@@ -1179,7 +1136,7 @@ class EditorTabs(QtWidgets.QWidget):
             )
             d.setFileMode(d.ExistingFiles)
             d.selectFile('"codeparser.py" "editorStack.py"')
-            d.exec_()
+            d.exec()
             if d.result():
                 filenames = d.selectedFiles()
             else:
@@ -1221,7 +1178,8 @@ class EditorTabs(QtWidgets.QWidget):
     def loadFile(self, filename, updateTabs=True, ignoreFail=False):
         """Load the specified file.
         On success returns the item of the file, also if it was
-        already open."""
+        already open.
+        """
 
         # Note that by giving the name of a tempfile, we can select that
         # temp file.
@@ -1237,11 +1195,23 @@ class EditorTabs(QtWidgets.QWidget):
             if item.id == filename:
                 # id gets _filename or _name for temp files
                 break
+            if os.path.isfile(filename) and os.path.isfile(item.filename):
+                if os.path.samefile(filename, item.filename):
+                    # file is already open, but with a different filepath
+                    # this could be, for example:
+                    # - a symbolic link to the other file
+                    # - or r"\\localhost\c$\temp\abc.py" and r"C:\temp\abc.py"
+                    break
         else:
             item = None
         if item:
             self._tabs.setCurrentItem(item)
-            print("File already open: '{}'".format(filename))
+            if filename.lower() != item.filename.lower() and item.filename != "":
+                # only print the message if something unexpected happened
+                if filename == item.filename:
+                    print("File already open: '{}'".format(filename))
+                else:
+                    print("File '{}' already open as '{}'".format(filename, item.filename))
             return item
 
         # create editor
@@ -1255,8 +1225,8 @@ class EditorTabs(QtWidgets.QWidget):
                 m = QtWidgets.QMessageBox(self)
                 m.setWindowTitle("Error loading file")
                 m.setText(str(err))
-                m.setIcon(m.Warning)
-                m.exec_()
+                m.setIcon(m.Icon.Warning)
+                m.exec()
             return None
 
         # create list item
@@ -1307,6 +1277,33 @@ class EditorTabs(QtWidgets.QWidget):
         # return lastopened item
         return item
 
+    def reloadFile(self, editor=None):
+        if editor is None:
+            editor = self.getCurrentEditor()
+            if editor is None:
+                return
+        if editor.name.startswith("<tmp"):
+            return
+
+        if editor.document().isModified():
+            dlg = QtWidgets.QMessageBox(self)
+            dlg.setWindowTitle("Reload file with unsaved changes?")
+            dlg.setText(
+                'Do you want to reload file\n"{}"\n'
+                "and lose unsaved changes?".format(editor.filename)
+            )
+            btnReload = dlg.addButton("Reload", QtWidgets.QMessageBox.ButtonRole.AcceptRole)
+            btnKeep = dlg.addButton(
+                "Keep this version", QtWidgets.QMessageBox.ButtonRole.RejectRole
+            )
+            dlg.setDefaultButton(btnKeep)
+            dlg.exec()
+            if dlg.clickedButton() != btnReload:
+                return  # cancel reloading
+
+        editor.reload()
+        self._tabs.updateItems()
+
     def saveFileAs(self, editor=None):
         """Create a dialog for the user to select a file.
         returns: True if succesfull, False if fails
@@ -1323,13 +1320,10 @@ class EditorTabs(QtWidgets.QWidget):
             startdir = os.path.dirname(editor._filename)
         else:
             startdir = self._lastpath
-            # Try the file browser or project manager to suggest a path
+            # Try the file browser to suggest a path
             fileBrowser = pyzo.toolManager.getTool("pyzofilebrowser")
-            projectManager = pyzo.toolManager.getTool("pyzoprojectmanager")
             if fileBrowser:
                 startdir = fileBrowser.getDefaultSavePath()
-            if projectManager and not startdir:
-                startdir = projectManager.getDefaultSavePath()
             if not startdir:
                 startdir = os.path.expanduser("~")
 
@@ -1343,11 +1337,9 @@ class EditorTabs(QtWidgets.QWidget):
         filter += "C (*.c *.h *.cpp);;"
         # filter += "Py+Cy+C (*.py *.pyw *.pyi *.pyx *.pxd *.c *.h *.cpp);;"
         filter += "All (*.*)"
-        filename = QtWidgets.QFileDialog.getSaveFileName(
+        filename, selectedFilter = QtWidgets.QFileDialog.getSaveFileName(
             self, msg, startdir, filter, options=self._fileDialogOptions
         )
-        if isinstance(filename, tuple):  # PySide
-            filename = filename[0]
 
         # give python extension if it has no extension
         head, tail = os.path.split(filename)
@@ -1393,8 +1385,8 @@ class EditorTabs(QtWidgets.QWidget):
             m = QtWidgets.QMessageBox(self)
             m.setWindowTitle("Error saving file")
             m.setText(str(err))
-            m.setIcon(m.Warning)
-            m.exec_()
+            m.setIcon(m.Icon.Warning)
+            m.exec()
             # Return now
             return False
 
@@ -1402,7 +1394,7 @@ class EditorTabs(QtWidgets.QWidget):
         filename = editor._filename
 
         # notify
-        # TODO: message concerining line endings
+        # TODO: message concerning line endings
         print("saved file: {} ({})".format(filename, editor.lineEndingsHumanReadable))
         self._tabs.updateItems()
 
@@ -1434,16 +1426,13 @@ class EditorTabs(QtWidgets.QWidget):
         return close_txt, discard_txt, cancel_txt, save_txt
 
     def askToSaveFileIfDirty(self, editor):
-        """askToSaveFileIfDirty(editor)
-
-        If the given file is not saved, pop up a dialog
+        """If the given file is not saved, pop up a dialog
         where the user can save the file
 
         Returns 1 if file need not be saved.
         Returns 2 if file was saved.
         Returns 3 if user discarded changes.
         Returns 0 if cancelled.
-
         """
 
         # should we ask to save the file?
@@ -1470,7 +1459,9 @@ class EditorTabs(QtWidgets.QWidget):
 
     def closeFile(self, editor=None):
         """Close the selected (or current) editor.
-        Returns same result as askToSaveFileIfDirty()"""
+
+        Returns same result as askToSaveFileIfDirty()
+        """
 
         # get editor
         if editor is None:
@@ -1554,6 +1545,7 @@ class EditorTabs(QtWidgets.QWidget):
 
     def _getCurrentOpenFilesAsSsdfList(self):
         """Get the state as it currently is as an ssdf list.
+
         The state entails all open files and their structure in the
         projects. The being collapsed of projects and their main files.
         The position of the cursor in the editors.
@@ -1584,10 +1576,7 @@ class EditorTabs(QtWidgets.QWidget):
             # Add to state
             state.append(tuple(info))
 
-        # Get history
-        history = [item for item in self._tabs._itemHistory]
-        history.reverse()  # Last one is current
-        for item in history:
+        for item in self._tabs._itemHistory[::-1]:
             if isinstance(item, FileItem):
                 ed = item._editor
                 if ed._filename:
@@ -1598,6 +1587,7 @@ class EditorTabs(QtWidgets.QWidget):
 
     def _setCurrentOpenFilesAsSsdfList(self, state):
         """Set the state of the editor in terms of opened files.
+
         The input should be a list object as returned by
         ._getCurrentOpenFilesAsSsdfList().
         """
@@ -1633,13 +1623,15 @@ class EditorTabs(QtWidgets.QWidget):
                             if "pinned" in item:
                                 itm._pinned = True
                         except Exception as err:
-                            print("Could not set position for %s" % fname, err)
+                            print("Could not set position for", fname, err)
 
         return len(fileItems) != 0
 
     def closeAll(self):
-        """Close all files (well technically, we don't really close them,
-        so that they are all stil there when the user presses cancel).
+        """Close all files
+
+        Well technically, we don't really close them, so that they
+        are all stil there when the user presses cancel.
         Returns False if the user pressed cancel when asked for
         saving an unsaved file.
         """
