@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
 # Pyzo is distributed under the terms of the 2-Clause BSD License.
@@ -48,17 +47,17 @@ def shellTitle(shell, moreinfo=False):
     stateText = shell._state or ""
 
     # Build text for elapsed time
-    elapsed = time.time() - shell._start_time
+    elapsed = int(time.time() - shell._start_time)
     hh = elapsed // 3600
     mm = (elapsed - hh * 3600) // 60
     ss = elapsed - hh * 3600 - mm * 60
-    runtimeText = "runtime: %i:%02i:%02i" % (hh, mm, ss)
+    runtimeText = "runtime: {}:{:02d}:{:02d}".format(hh, mm, ss)
 
     # Build text
     if not moreinfo:
         text = nameText
     else:
-        text = "'%s' (%s %s) - %s, %s" % (
+        text = "'{}' ({} {}) - {}, {}".format(
             nameText,
             versionText,
             guiText,
@@ -90,7 +89,7 @@ class ShellStackWidget(QtWidgets.QWidget):
     currentShellStateChanged = QtCore.Signal()
 
     def __init__(self, parent):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         # create toolbar
         self._toolbar = QtWidgets.QToolBar(self)
@@ -143,8 +142,7 @@ class ShellStackWidget(QtWidgets.QWidget):
             self._interpreterhelp.detect()
 
     def addShell(self, shellInfo=None):
-        """addShell()
-        Add a shell to the widget."""
+        """Add a shell to the widget."""
 
         # Create shell and add to stack
         shell = PythonShell(self, shellInfo)
@@ -158,9 +156,7 @@ class ShellStackWidget(QtWidgets.QWidget):
         return shell
 
     def removeShell(self, shell):
-        """removeShell()
-        Remove an existing shell from the widget
-        """
+        """Remove an existing shell from the widget"""
         self._stack.removeWidget(shell)
 
     def onCurrentChanged(self, index):
@@ -214,9 +210,7 @@ class ShellStackWidget(QtWidgets.QWidget):
             self.currentShellStateChanged.emit()
 
     def getCurrentShell(self):
-        """getCurrentShell()
-        Get the currently active shell.
-        """
+        """Get the currently active shell."""
 
         w = None
         if self._stack.count():
@@ -238,8 +232,7 @@ class ShellStackWidget(QtWidgets.QWidget):
         return shells
 
     def getShellAt(self, i):
-        return
-        """ Get shell at current tab index """
+        """Get shell at current tab index"""
 
         return self._stack.widget(i)
 
@@ -254,7 +247,7 @@ class ShellStackWidget(QtWidgets.QWidget):
         )
 
         # Also give it a context menu
-        self._shellButton.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+        self._shellButton.setContextMenuPolicy(QtCore.Qt.ContextMenuPolicy.CustomContextMenu)
         self._shellButton.customContextMenuRequested.connect(self.contextMenuTriggered)
 
         # Add actions
@@ -292,7 +285,7 @@ class ShellControl(QtWidgets.QToolButton):
     """A button that can be used to select a shell and start a new shell."""
 
     def __init__(self, parent, shellStack):
-        QtWidgets.QToolButton.__init__(self, parent)
+        super().__init__(parent)
 
         # Store reference of shell stack
         self._shellStack = shellStack
@@ -303,8 +296,8 @@ class ShellControl(QtWidgets.QToolButton):
         # Set text and tooltip
         self.setText("Warming up ...")
         self.setToolTip(translate("shells", "Click to select shell."))
-        self.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
-        self.setPopupMode(self.InstantPopup)
+        self.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+        self.setPopupMode(self.ToolButtonPopupMode.InstantPopup)
 
         # Set icon
         self._iconMaker = ShellIconMaker(self)
@@ -344,7 +337,7 @@ class ShellControl(QtWidgets.QToolButton):
                 action.setText(shellTitle(shellToUpdate, True))
 
         # Any items left in shells need a menu item
-        # Dont give them an icon, or the icon is used as checkbox thingy
+        # Don't give them an icon, or the icon is used as checkbox thingy
         for shell in shells:
             text = shellTitle(shell)
             action = menu.addItem(text, None, self._shellStack.setCurrentWidget, shell)
@@ -361,7 +354,7 @@ class ShellControl(QtWidgets.QToolButton):
             self.setText("No shell selected")
 
     def onElapsedTimesTimer(self):
-        # Automatically turn timer off is menu is hidden
+        # Automatically turn timer off if menu is hidden
         if not self.menu().isVisible():
             self._elapsedTimesTimer.stop()
             return
@@ -377,7 +370,7 @@ class ShellControl(QtWidgets.QToolButton):
 #     """
 #
 #     def __init__(self, parent):
-#         QtWidgets.QToolButton.__init__(self, parent)
+#         super().__init__(parent)
 #
 #         # Flag
 #         self._debugmode = False
@@ -385,8 +378,8 @@ class ShellControl(QtWidgets.QToolButton):
 #         # Set text
 #         self.setText(translate('debug', 'Debug'))
 #         self.setIcon(pyzo.icons.bug)
-#         self.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
-#         #self.setPopupMode(self.InstantPopup)
+#         self.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+#         #self.setPopupMode(self.ToolButtonPopupMode.InstantPopup)
 #
 #         # Bind to triggers
 #         self.triggered.connect(self.onTriggered)
@@ -458,7 +451,7 @@ class ShellControl(QtWidgets.QToolButton):
 #             command = action.cmd.upper()
 #             shell = pyzo.shells.getCurrentShell()
 #             if shell:
-#                 shell.executeCommand('DB %s\n' % command)
+#                 shell.executeCommand('DB {}\n'.format(command))
 #
 #
 #     def setTrace(self, info):
@@ -474,14 +467,14 @@ class DebugStack(QtWidgets.QToolButton):
     """A button that shows the stack trace."""
 
     def __init__(self, parent):
-        QtWidgets.QToolButton.__init__(self, parent)
+        super().__init__(parent)
 
         # Set text and tooltip
         self._baseText = translate("debug", "Stack")
-        self.setText("%s:" % self._baseText)
+        self.setText("{}:".format(self._baseText))
         self.setIcon(pyzo.icons.text_align_justify)
-        self.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
-        self.setPopupMode(self.InstantPopup)
+        self.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+        self.setPopupMode(self.ToolButtonPopupMode.InstantPopup)
 
         # Bind to triggers
         self.triggered.connect(self.onTriggered)
@@ -501,9 +494,10 @@ class DebugStack(QtWidgets.QToolButton):
             self.debugFocus(line)
 
     def setTrace(self, info):
-        """Set the stack trace. This method is called from
-        the shell that receives the trace via its status channel
-        directly from the interpreter.
+        """Set the stack trace.
+
+        This method is called from the shell that receives the trace via its
+        status channel directly from the interpreter.
         If trace is None, removes the trace
         """
 
@@ -564,33 +558,44 @@ class DebugStack(QtWidgets.QToolButton):
             self.setEnabled(True)
 
     def debugFocus(self, lineFromDebugState):
-        """debugFocus(lineFromDebugState)
-        Open the file and show the linenr of the given lineFromDebugState.
-        """
+        """Open the file and show the linenr of the given lineFromDebugState."""
+        error = None
         # Get filenr and item
         try:
             tmp = lineFromDebugState.split(", in ")[0].split(", line ")
             filename = tmp[0][len("File ") :].strip('"')
             linenr = int(tmp[1].strip())
         except Exception:
-            return "Could not focus!"
-        # Cannot open <console>
-        if filename == "<console>":
-            return "Stack frame is <console>."
-        elif filename.startswith("<ipython-input-"):
-            return "Stack frame is IPython input."
-        # Go there!
-        result = pyzo.editors.loadFile(filename)
-        if not result:
-            return "Could not open file where the error occured."
+            error = "Could not focus!"
         else:
-            editor = result._editor
+            if filename in (
+                "<console>",
+                "<string>",
+                "<startup>",
+                "<startup_after_gui>",
+            ):
+                error = "Stack frame is {}.".format(filename)
+            elif filename.startswith("<ipython-input-"):
+                error = "Stack frame is IPython input."
+            else:
+                # Go there!
+                fileItem = pyzo.editors.loadFile(filename)
+                if not fileItem:
+                    error = "Could not open file where the error occured."
+        if error is None:
+            editor = fileItem._editor
             # Goto line and select it
             editor.gotoLine(linenr)
             cursor = editor.textCursor()
-            cursor.movePosition(cursor.StartOfBlock)
-            cursor.movePosition(cursor.EndOfBlock, cursor.KeepAnchor)
+            cursor.movePosition(cursor.MoveOperation.StartOfBlock)
+            cursor.movePosition(cursor.MoveOperation.EndOfBlock, cursor.MoveMode.KeepAnchor)
             editor.setTextCursor(cursor)
+        else:
+            # focus on shell and not on an editor because there is no valid file
+            shell = pyzo.shells.getCurrentShell()
+            if shell:
+                shell.setFocus()
+        return error
 
 
 class InterpreterHelper(QtWidgets.QWidget):
@@ -600,7 +605,7 @@ class InterpreterHelper(QtWidgets.QWidget):
         super().__init__(parent)
 
         self._label = QtWidgets.QLabel("hello world")
-        self._label.setTextFormat(QtCore.Qt.RichText)
+        self._label.setTextFormat(QtCore.Qt.TextFormat.RichText)
         self._label.setWordWrap(True)
         # self._label.setOpenExternalLinks(True)
         self._label.linkActivated.connect(self.handle_link)
@@ -643,52 +648,52 @@ class InterpreterHelper(QtWidgets.QWidget):
         if conda_interpreters and conda_interpreters[0].version > "3":
             self._the_exe = conda_interpreters[0].path
             text = """Pyzo detected a conda environment in:
-                      <br />%s<br /><br />
+                      <br />{}<br /><br />
                       You can <a href='usefound'>use&nbsp;this&nbsp;environment</a>
                       (recommended), or manually specify an interpreter
                       by setting the exe in the <a href='config'>shell&nbsp;config</a>.
                       <br /><br />Click one of the links above, or <a href='refresh'>refresh</a>.
-                   """ % (
+                   """.format(
                 self._the_exe,
             )
         elif interpreters and interpreters[0].version > "3":
             self._the_exe = interpreters[0].path
             text = """Pyzo detected a Python interpreter in:
-                      <br />%s<br /><br />
+                      <br />{}<br /><br />
                       You can <a href='usefound'>use&nbsp;this&nbsp;environment</a>
                       (recommended), or manually specify an interpreter
                       by setting the exe in the <a href='config'>shell&nbsp;config</a>.
                       <br /><br />Click one of the links above, or <a href='refresh'>refresh</a>.
-                   """ % (
+                   """.format(
                 self._the_exe,
             )
         elif interpreters:
             text = """Pyzo detected a Python interpreter,
                       but it is Python 2. We strongly recommend using Python 3 instead.
                       <br /><br />
-                      If you installed %s or %s in a non-default location,
+                      If you installed {} or {} in a non-default location,
                       or if you want to manually specify an interpreter,
                       set the exe in the <a href='config'>shell&nbsp;config</a>.
                       <br /><br />Click one of the links above, or <a href='refresh'>refresh</a>.
-                   """ % (
+                   """.format(
                 python_link,
                 conda_link,
             )
         else:
             text = """Pyzo did not detect any Python interpreters.
-                      We recomment installing %s or %s
+                      We recomment installing {} or {}
                       (and click <a href='refresh'>refresh</a> when done).
                       <br /><br />
                       If you installed Python or Miniconda in a non-default location,
                       or if you want to manually specify the interpreter,
                       set the exe in the <a href='config'>shell&nbsp;config</a>.
-                   """ % (
+                   """.format(
                 python_link,
                 conda_link,
             )
 
         link_style = "font-weight: bold; color:#369; text-decoration:underline;"
-        self._label.setText(text.replace("<a ", '<a style="%s" ' % link_style))
+        self._label.setText(text.replace("<a ", '<a style="{}" '.format(link_style)))
 
     def handle_link(self, url):
         if url == "refresh":
@@ -700,13 +705,13 @@ class InterpreterHelper(QtWidgets.QWidget):
         elif url.startswith(("http://", "https://")):
             webbrowser.open(url)
         else:
-            raise ValueError("Unknown link in conda helper: %s" % url)
+            raise ValueError("Unknown link in conda helper: {}".format(url))
 
     def editShellConfig(self):
         from pyzo.core.shellInfoDialog import ShellInfoDialog
 
         d = ShellInfoDialog()
-        d.exec_()
+        d.exec()
         self.refresh()
         self.restart_shell()
 
