@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
 # Pyzo is distributed under the terms of the 2-Clause BSD License.
@@ -13,7 +12,7 @@ Defines splash window shown during startup.
 import os
 
 import pyzo
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 from pyzo import translate
 
 STYLESHEET = """
@@ -21,7 +20,7 @@ QWidget {
     background-color: #268bd2;
 }
 QFrame {
-    background-image: url("%s");
+    background-image: url("{IMAGE_URL}");
     background-repeat: no-repeat;
     background-position: center;
 }
@@ -35,25 +34,25 @@ QLabel {
 splash_text = """
 <p>{text_title}</p>
 <p>{text_version} {version}</p>
-<p>{text_os} <a href='http://pyzo.org/'>http://pyzo.org</a></p>
+<p>{text_os} <a href='https://pyzo.org/'>https://pyzo.org</a></p>
 """
 
 
 class LogoWidget(QtWidgets.QFrame):
     def __init__(self, parent):
-        QtWidgets.QFrame.__init__(self, parent)
+        super().__init__(parent)
         self.setMinimumSize(256, 256)
         self.setMaximumSize(256, 256)
 
 
 class LabelWidget(QtWidgets.QWidget):
     def __init__(self, parent, distro=None):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
         self.setMinimumSize(360, 256)  # Ensure title fits nicely
 
         # Create label widget and costumize
         self._label = QtWidgets.QLabel(self)
-        self._label.setTextFormat(QtCore.Qt.RichText)
+        self._label.setTextFormat(QtCore.Qt.TextFormat.RichText)
         self._label.setOpenExternalLinks(True)
         self._label.setWordWrap(True)
         self._label.setMargin(20)
@@ -89,11 +88,10 @@ class LabelWidget(QtWidgets.QWidget):
 
 
 class SplashWidget(QtWidgets.QWidget):
-    """ A splash widget.
-    """
+    """A splash widget."""
 
     def __init__(self, parent, **kwargs):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         self._left = LogoWidget(self)
         self._right = LabelWidget(self, **kwargs)
@@ -101,18 +99,18 @@ class SplashWidget(QtWidgets.QWidget):
         # Layout
         layout = QtWidgets.QHBoxLayout(self)
         self.setLayout(layout)
-        # layout.setContentsMargins(0,0,0,0)
+        # layout.setContentsMargins(0, 0, 0, 0)
         layout.setSpacing(25)
         layout.addStretch(1)
         layout.addWidget(self._left, 0)
         layout.addWidget(self._right, 0)
         layout.addStretch(1)
 
-        # Change background of main window to create a splash-screen-efefct
+        # Change background of main window to create a splash-screen-effect
         iconImage = "pyzologo256.png"
         iconImage = os.path.join(pyzo.pyzoDir, "resources", "appicons", iconImage)
         iconImage = iconImage.replace(os.path.sep, "/")  # Fix for Windows
-        self.setStyleSheet(STYLESHEET % iconImage)
+        self.setStyleSheet(STYLESHEET.replace("{IMAGE_URL}", iconImage))
 
 
 if __name__ == "__main__":
