@@ -76,11 +76,7 @@ class App_base:
         # real event loop though, that is fast when needed and just sleeps
         # when the gui is idle, saving battery life.
 
-        if hasattr(time, "perf_counter"):
-            perf_counter = time.perf_counter
-        else:
-            perf_counter = time.time
-        perf_counter
+        perf_counter = getattr(time, "perf_counter", time.time)
 
         repl_time = 0.099
         next_repl = perf_counter() + repl_time
@@ -115,10 +111,10 @@ class App_nogui(App_base):
 
     def run(self, repl_callback):
         # Move at a slow pace - there is no gui to keep running
-        super().run(repl_callback, 0.1)
+        App_base.run(self, repl_callback, 0.1)
 
 
-# Experimental and WIP - not used at the moment
+# Experimental and WIP
 class App_asyncio_new(App_base):
     """Based on asyncio (standard Python) event loop.
 
@@ -137,7 +133,14 @@ class App_asyncio_new(App_base):
         self._repl_callback = repl_callback
         self._sleep_time = 0.1
 
-        loop = asyncio.get_event_loop_policy().get_event_loop()
+        if sys.version_info < (3, 12):
+            loop = asyncio.get_event_loop_policy().get_event_loop()
+        else:
+            try:
+                loop = asyncio.get_running_loop()
+            except RuntimeError:
+                # no running event loop
+                loop = asyncio.new_event_loop()
         self.enable(loop, True)
 
     def enable(self, loop, run=False):
@@ -153,8 +156,13 @@ class App_asyncio_new(App_base):
                 old_loop.stop()
             self._loop = new_loop
             if not new_loop.is_running():
-                new_loop.original_run_forever(*args, **kwargs)
-
+                while True:
+                    try:
+                        new_loop.original_run_forever(*args, **kwargs)
+                        break
+                    except KeyboardInterrupt:
+                        self._keyboard_interrupt()
+                        continue
         if not hasattr(new_loop, "original_run_forever"):
             new_loop.original_run_forever = new_loop.run_forever
         new_loop.run_forever = new_run_forever
@@ -170,7 +178,7 @@ class App_asyncio_new(App_base):
         except Exception:
             loop = None
 
-        # If its the same as our current loop, we want to be called again
+        # If it's the same as our current loop, we want to be called again
         if loop:
             self._loop.call_later(self._sleep_time, self._ping_repl_callback)
 
@@ -468,18 +476,15 @@ class App_qt(App_base):
 
             def __new__(cls, *args, **kwargs):
                 # Get the singleton application instance
-                theApp = QApplication_hijacked.instance()
+                theApp = cls.instance()
 
                 # Instantiate an original QApplication instance if we need to
                 if theApp is None:
                     theApp = QtGui.real_QApplication(*args, **kwargs)
                     QtGui.qApp = theApp
 
-                # Add attributes of cls to the instance to make it
-                # behave as if it were an instance of that class
-                for key in dir(cls):
-                    # Skip all magic methods except __init__
-                    if key.startswith("__") and key != "__init__":
+                for key in ["__init__", "exec_", "quit"]:
+                    if not hasattr(cls, key):
                         continue
                     # Skip attributes that we already have
                     val = getattr(cls, key)
