@@ -104,15 +104,20 @@ def _should_not_interpret_as_magic(line):
         return True
     pos = pos + 1
     # command is alone on the line
-    if pos >= len(ltok) or ltok[pos].type in [token.ENDMARKER, tokenize.COMMENT]:
+    if pos >= len(ltok) or ltok[pos].type in [
+        token.ENDMARKER,
+        token.NEWLINE,
+        token.COMMENT,
+    ]:
         if command in interpreter.locals:
             return True
         if interpreter.globals and command in interpreter.globals:
             return True
     else:  # command is not alone ; next token should not be an operator (this includes parentheses)
-        if ltok[pos].type == token.OP and not line.endswith("?"):
-            return True
-
+        if ltok[pos].type == token.OP:
+            # this is not a magic command: "b = a > 1  # is valid?"
+            if not line.endswith("?") or "#" in line:
+                return True
     return False
 
 
@@ -131,12 +136,10 @@ class Magician:
         return eval(command, {}, NS)
 
     def convert_command(self, line):
-        """convert_command(line)
+        """Convert a given command from a magic command to Python code.
 
-        Convert a given command from a magic command to Python code.
         Returns the converted command if it was a magic command, or
         the original otherwise.
-
         """
         # Get converted command, catch and report errors
         try:
@@ -180,7 +183,7 @@ class Magician:
                 if _should_not_interpret_as_magic(line):
                     return
             except Exception:
-                pass  # dont break interpreter if above func has a bug ...
+                pass  # don't break interpreter if above func has a bug ...
 
         else:
             # Old, not as good check for outdated Python version
@@ -208,12 +211,12 @@ class Magician:
         elif command.startswith("INSTALL"):
             return self.install(line, command)
 
-        elif command.startswith("UPDATE") or command.startswith("UPGRADE"):
+        elif command.startswith(("UPDATE", "UPGRADE")):
             line = line.replace("upgrade", "update")
             command = command.replace("UPGRADE", "UPDATE")
             return self.update(line, command)
 
-        elif command.startswith("REMOVE") or command.startswith("UNINSTALL"):
+        elif command.startswith(("REMOVE", "UNINSTALL")):
             line = line.replace("uninstall", "remove")
             return self.remove(line, command)
 
@@ -608,42 +611,6 @@ class Magician:
 
         return ""
 
-    # todo: I think we can deprecate this
-    def _check_imported_modules(self):
-        KNOWN_PURE_PYHON = (
-            "conda",
-            "yaml",
-            "IPython",
-            "requests",
-            "readline",
-            "pyreadline",
-        )
-        if not sys.platform.startswith("win"):
-            return  # Only a problem on Windows
-        # Check what modules are currently imported
-        loaded_modules = set()
-        for name, mod in sys.modules.items():
-            if "site-packages" in getattr(mod, "__file__", ""):
-                name = name.split(".")[0]
-                if name.startswith("_") or name in KNOWN_PURE_PYHON:
-                    continue
-                loaded_modules.add(name)
-        # Add PySide PyQt4 from IEP if prefix is the same
-        if os.getenv("IEP_PREFIX", "") == sys.prefix:
-            loaded_modules.add(os.getenv("IEP_QTLIB", "qt"))
-        # Warn if we have any such modules
-        loaded_modules = [m.lower() for m in loaded_modules if m]
-        if loaded_modules:
-            print("WARNING! The following modules are currently loaded:\n")
-            print("  " + ", ".join(sorted(loaded_modules)))
-            print(
-                "\nUpdating or removing them may fail if they are not "
-                "pure Python.\nIf none of the listed packages is updated or "
-                'removed, it is safe\nto proceed (use "f" if necessary).\n'
-            )
-            print("-" * 80)
-            time.sleep(2.0)  # Give user time to realize there is a warning
-
     def pip(self, line, command):
         if not (command == "PIP" or command.startswith("PIP ")):
             return
@@ -698,10 +665,16 @@ class Magician:
         oldargs = sys.argv
         try:
             try:
-                import notebook.notebookapp
+                import notebook  # noqa: just want to check if the module is there at all
+                from notebook._version import version_info
+
+                if version_info >= (7, 0):
+                    from notebook.app import main as run_notebook_app
+                else:
+                    from notebook.notebookapp import main as run_notebook_app
 
                 sys.argv = ["jupyter_notebook"] + list(args)
-                notebook.notebookapp.main()
+                run_notebook_app()
             except SystemExit:  # as err:
                 type, err, tb = sys.exc_info()
                 del tb
