@@ -13,14 +13,14 @@ from .utils import cleanpath, isdir
 
 class Browser(QtWidgets.QWidget):
     """A browser consists of an address bar, and tree view, and other
-    widets to help browse the file system. The browser object is responsible
+    widgets to help browse the file system. The browser object is responsible
     for tying the different browser-components together.
 
     It is also provides the API for dealing with starred dirs.
     """
 
     def __init__(self, parent, config, path=None):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         # Store config
         self.config = config
@@ -110,8 +110,15 @@ class Browser(QtWidgets.QWidget):
             "matchCase": self.config.searchMatchCase,
             "regExp": self.config.searchRegExp,
             "subDirs": self.config.searchSubDirs,
+            "excludeBinary": self.config.searchExcludeBinary,
         }
 
+    def setSearchText(self, needle, setFocus=False):
+        """Set the text in the search field."""
+        self._searchFilter.setText(needle)
+        if setFocus:
+            self._searchFilter.setFocus()
+
     @property
     def expandedDirs(self):
         """The list of the expanded directories."""
@@ -168,9 +175,7 @@ class Browser(QtWidgets.QWidget):
         self._tree.clear()
 
         # items.sort(key=lambda x: x._path)
-        items = [item for item in reversed(items)]
-
-        for item in items:
+        for item in items[::-1]:
             self._tree.addTopLevelItem(item)
 
     def currentProject(self):
@@ -182,7 +187,7 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
     """Line edit to which tool buttons (with icons) can be attached."""
 
     def __init__(self, parent):
-        QtWidgets.QLineEdit.__init__(self, parent)
+        super().__init__(parent)
         self._leftButtons = []
         self._rightButtons = []
 
@@ -202,11 +207,11 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
         button.setStyleSheet("QToolButton { border: none; padding: 0px; }")
         # button.setStyleSheet("QToolButton { border: none; padding: 0px; background-color:red;}");
         # Set behavior
-        button.setCursor(QtCore.Qt.ArrowCursor)
-        button.setPopupMode(button.InstantPopup)
+        button.setCursor(QtCore.Qt.CursorShape.ArrowCursor)
+        button.setPopupMode(button.ToolButtonPopupMode.InstantPopup)
         # Customize alignment
         if willHaveMenu:
-            button.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
+            button.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
             if sys.platform.startswith("win"):
                 button.setText(" ")
         # Update self
@@ -223,11 +228,11 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
         self._updateGeometry()
 
     def resizeEvent(self, event):
-        QtWidgets.QLineEdit.resizeEvent(self, event)
+        super().resizeEvent(event)
         self._updateGeometry(True)
 
     def showEvent(self, event):
-        QtWidgets.QLineEdit.showEvent(self, event)
+        super().showEvent(event)
         self._updateGeometry()
 
     def _updateGeometry(self, light=False):
@@ -261,13 +266,13 @@ class LineEditWithToolButtons(QtWidgets.QLineEdit):
                 )
 
         # Set padding
-        ss = "QLineEdit { padding-left: %ipx; padding-right: %ipx} "
-        self.setStyleSheet(ss % (paddingLeft, paddingRight))
+        ss = "QLineEdit {{ padding-left: {}px; padding-right: {}px}} "
+        self.setStyleSheet(ss.format(paddingLeft, paddingRight))
 
         # Set minimum size
         if not light:
             fw = QtWidgets.qApp.style().pixelMetric(
-                QtWidgets.QStyle.PM_DefaultFrameWidth
+                QtWidgets.QStyle.PixelMetric.PM_DefaultFrameWidth
             )
             msz = self.minimumSizeHint()
             w = max(msz.width(), paddingLeft + paddingRight + 10)
@@ -284,23 +289,23 @@ class PathInput(LineEditWithToolButtons):
     dirUp = QtCore.Signal()  # Emitted when user presses the up button
 
     def __init__(self, parent):
-        LineEditWithToolButtons.__init__(self, parent)
+        super().__init__(parent)
 
         # Create up button
         self._upBut = self.addButtonLeft(pyzo.icons.folder_parent)
         self._upBut.clicked.connect(self.dirUp)
 
         # To receive focus events
-        self.setFocusPolicy(QtCore.Qt.StrongFocus)
+        self.setFocusPolicy(QtCore.Qt.FocusPolicy.StrongFocus)
 
         # Set completion mode
         self.setCompleter(QtWidgets.QCompleter())
         c = self.completer()
-        c.setCompletionMode(c.InlineCompletion)
+        c.setCompletionMode(c.CompletionMode.InlineCompletion)
 
         # Set dir model to completer
         self._dirModel = QtWidgets.QFileSystemModel(c)
-        self._dirModel.setFilter(QtCore.QDir.Dirs | QtCore.QDir.NoDotAndDotDot)
+        self._dirModel.setFilter(QtCore.QDir.Filter.Dirs | QtCore.QDir.Filter.NoDotAndDotDot)
         # filter is not synchronized with NameFilter input (e.g. "!hidden")
         c.setModel(self._dirModel)
         if sys.platform != "win32":
@@ -344,8 +349,8 @@ class PathInput(LineEditWithToolButtons):
         # invoke checking whether the current text is a valid directory.
         # Test if QtGui is not None (can happen when reloading tools)
         if QtGui and isinstance(event, QtGui.QKeyEvent):
-            qt = QtCore.Qt
-            if event.key() in [qt.Key_Tab, qt.Key_Enter, qt.Key_Return]:
+            k = QtCore.Qt.Key
+            if event.key() in [k.Key_Tab, k.Key_Enter, k.Key_Return]:
                 self.setText(self.text())  # Apply completion
                 self.onTextEdited()  # Check if this is a valid dir
                 return True
@@ -357,11 +362,9 @@ class PathInput(LineEditWithToolButtons):
             self.dirChanged.emit(cleanpath(text))
 
     def focusOutEvent(self, event=None):
-        """focusOutEvent(event)
-        On focusing out, make sure that the set path is correct.
-        """
+        """On focusing out, make sure that the set path is correct."""
         if event is not None:
-            QtWidgets.QLineEdit.focusOutEvent(self, event)
+            super().focusOutEvent(event)
 
         path = self.parent()._tree.path()
         self.setPath(path)
@@ -371,7 +374,7 @@ class Projects(QtWidgets.QWidget):
     dirChanged = QtCore.Signal(str)  # Emitted when the user changes the project
 
     def __init__(self, parent):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         # Init variables
         self._path = ""
@@ -386,8 +389,8 @@ class Projects(QtWidgets.QWidget):
         self._but.setIcon(pyzo.icons.star3)
         self._but.setStyleSheet("QToolButton { padding: 0px; }")
         self._but.setIconSize(QtCore.QSize(18, 18))
-        self._but.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
-        self._but.setPopupMode(self._but.InstantPopup)
+        self._but.setToolButtonStyle(QtCore.Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
+        self._but.setPopupMode(self._but.ToolButtonPopupMode.InstantPopup)
         #
         self._menu = QtWidgets.QMenu(self._but)
         self._menu.triggered.connect(self.onMenuTriggered)
@@ -494,15 +497,13 @@ class Projects(QtWidgets.QWidget):
 
         elif action._id == "name":
             # Open dialog to ask for name
-            name = QtWidgets.QInputDialog.getText(
+            name, ok = QtWidgets.QInputDialog.getText(
                 self.parent(),
                 translate("filebrowser", "Project name"),
                 translate("filebrowser", "New project name:"),
                 text=d["name"],
             )
-            if isinstance(name, tuple):
-                name = name[0] if name[1] else ""
-            if name:
+            if name and ok:
                 d["name"] = name
             self.updateProjectList()
 
@@ -543,7 +544,7 @@ class NameFilter(LineEditWithToolButtons):
     filterChanged = QtCore.Signal()
 
     def __init__(self, parent):
-        LineEditWithToolButtons.__init__(self, parent)
+        super().__init__(parent)
 
         # Create tool button, and attach the menu
         self._menuBut = self.addButtonRight(pyzo.icons["filter"], True)
@@ -575,7 +576,7 @@ class NameFilter(LineEditWithToolButtons):
 
     def setText(self, value, test=False):
         """To initialize the name filter."""
-        QtWidgets.QLineEdit.setText(self, value)
+        super().setText(value)
         if test:
             self.checkFilterValue()
         self._lastValue = value
@@ -597,7 +598,7 @@ class SearchFilter(LineEditWithToolButtons):
     filterChanged = QtCore.Signal()
 
     def __init__(self, parent):
-        LineEditWithToolButtons.__init__(self, parent)
+        super().__init__(parent)
 
         # Create tool button, and attach the menu
         self._menuBut = self.addButtonRight(pyzo.icons["magnifier"], True)
@@ -622,7 +623,7 @@ class SearchFilter(LineEditWithToolButtons):
     def onCancelPressed(self):
         """Clear text or build menu."""
         if self.text():
-            QtWidgets.QLineEdit.clear(self)
+            super().clear()
             self.checkFilterValue()
         else:
             self.buildMenu()
@@ -650,6 +651,7 @@ class SearchFilter(LineEditWithToolButtons):
             ("searchMatchCase", False, translate("filebrowser", "Match case")),
             ("searchRegExp", False, translate("filebrowser", "RegExp")),
             ("searchSubDirs", True, translate("filebrowser", "Search in subdirs")),
+            ("searchExcludeBinary", True, translate("filebrowser", "Exclude binary")),
         ]
 
         # Fill menu
