@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
 # Pyzo is distributed under the terms of the 2-Clause BSD License.
@@ -7,7 +6,7 @@
 
 import sys, os, code
 import pyzo
-from pyzo.util.qt import QtCore, QtGui, QtWidgets  # noqa
+from pyzo.qt import QtCore, QtGui, QtWidgets  # noqa
 from pyzo.core.shell import BaseShell
 from pyzo.core.pyzoLogging import splitConsole
 
@@ -23,7 +22,7 @@ class PyzoLogger(QtWidgets.QWidget):
     """
 
     def __init__(self, parent):
-        QtWidgets.QWidget.__init__(self, parent)
+        super().__init__(parent)
 
         # logger widget
         self._logger_shell = PyzoLoggerShell(self)
@@ -52,16 +51,22 @@ class PyzoLoggerShell(BaseShell):
     """
 
     def __init__(self, parent):
-        BaseShell.__init__(self, parent)
+        super().__init__(parent)
 
         # Set style to Python, or autocompletion does not work
         self.setParser("python")
 
         # Change background color to make the logger look different from shell
-        # Use color as if all lines are highlighted
         f1 = self.getStyleElementFormat("Editor.text")
-        f2 = self.getStyleElementFormat("Editor.Highlight current line")
-        newStyle = "back:%s, fore:%s" % (f2.back.name(), f1.fore.name())
+        fgColor = QtGui.QColor(f1.fore.name())
+        bgColor = QtGui.QColor(f1.back.name())
+        if pyzo.darkSyntax:
+            fgColor = fgColor.lighter(150)
+            bgColor = bgColor.lighter(150)
+        else:
+            fgColor = fgColor.darker(150)
+            bgColor = bgColor.darker(110)
+        newStyle = "back:{}, fore:{}".format(bgColor.name(), fgColor.name())
         self.setStyle(editor_text=newStyle)
 
         # Create namespace for logger interpreter
@@ -74,10 +79,9 @@ class PyzoLoggerShell(BaseShell):
         self._interpreter = code.InteractiveConsole(locals, "<logger>")
 
         # Show welcome text
+        version = sys.version.split(None, 1)[0]
         moreBanner = "This is the Pyzo logger shell."
-        self.write(
-            "Python %s on %s - %s\n\n" % (sys.version[:5], sys.platform, moreBanner)
-        )
+        self.write("Python {} on {} - {}\n\n".format(version, sys.platform, moreBanner))
         self.write(str(sys.ps1), 2)
 
         # Split console
@@ -101,7 +105,7 @@ class PyzoLoggerShell(BaseShell):
 
     def writeErr(self, msg):
         """This is what the logger uses to write errors."""
-        self.write(msg, 0, "#C00")
+        self.write(msg, 0, "#f00")
 
     # Note that I did not (yet) implement calltips
 
@@ -112,7 +116,7 @@ class PyzoLoggerShell(BaseShell):
         if aco.tryUsingBuffer():
             return
 
-        # Include buildins?
+        # Include builtins?
         if not aco.name:
             command = "__builtins__.keys()"
             try:
