@@ -10,7 +10,7 @@ import time
 import socket
 import threading
 
-from yoton.misc import basestring, bytes, str
+from yoton.misc import basestring, str
 from yoton.misc import getErrorMsg, UID
 from yoton.misc import TinyPackageQueue
 from yoton.core import Package, PACKAGE_HEARTBEAT, PACKAGE_CLOSE, EINTR
@@ -42,13 +42,13 @@ class TcpConnection(Connection):
     """TcpConnection(context, name='')
 
     The TcpConnection class implements a connection between two
-    contexts that are in differenr processes or on different machines
+    contexts that are in different processes or on different machines
     connected via the internet.
 
     This class handles the low-level communication for the context.
     A ContextConnection instance wraps a single BSD socket for its
     communication, and uses TCP/IP as the underlying communication
-    protocol. A persisten connection is used (the BSD sockets stay
+    protocol. A persistent connection is used (the BSD sockets stay
     connected). This allows to better distinguish between connection
     problems and timeouts caused by the other side being busy.
 
@@ -77,23 +77,21 @@ class TcpConnection(Connection):
         """
 
         # Lock the connection while we change its status
-        self._lock.acquire()
+        with self._lock:
+            # Update hostname and port number; for hosting connections the port
+            # may be different if max_tries > 0. Each client connection will be
+            # assigned a different ephemeral port number.
+            # http://www.tcpipguide.com/free/t_TCPPortsConnectionsandConnectionIdentification-2.htm
+            # Also get hostname and port for other end
+            if bsd_socket is not None:
+                if True:
+                    self._hostname1, self._port1 = bsd_socket.getsockname()
+                if status != STATUS_WAITING:
+                    self._hostname2, self._port2 = bsd_socket.getpeername()
 
-        # Update hostname and port number; for hosting connections the port
-        # may be different if max_tries > 0. Each client connection will be
-        # assigned a different ephemeral port number.
-        # http://www.tcpipguide.com/free/t_TCPPortsConnectionsandConnectionIdentification-2.htm
-        # Also get hostname and port for other end
-        if bsd_socket is not None:
-            if True:
-                self._hostname1, self._port1 = bsd_socket.getsockname()
-            if status != STATUS_WAITING:
-                self._hostname2, self._port2 = bsd_socket.getpeername()
+            # Set status as normal
+            Connection._set_status(self, status)
 
-        # Set status as normal
-        Connection._set_status(self, status)
-
-        try:
             if status in [STATUS_HOSTING, STATUS_CONNECTED]:
                 # Really connected
 
@@ -111,7 +109,7 @@ class TcpConnection(Connection):
                 self._sendingThread.start()
                 self._receivingThread.start()
 
-            if status == 0:
+            if status == STATUS_CLOSED:
                 # Close bsd socket
                 try:
                     self._bsd_socket.shutdown()
@@ -127,9 +125,6 @@ class TcpConnection(Connection):
                 self._sendingThread = None
                 self._receivingThread = None
 
-        finally:
-            self._lock.release()
-
     def _bind(self, hostname, port, max_tries=1):
         """Bind the bsd socket. Launches a dedicated thread that waits
         for incoming connections and to do the handshaking procedure.
@@ -157,9 +152,9 @@ class TcpConnection(Connection):
         if not sys.platform.startswith("win"):
             s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
 
-        # Try all ports in the specified range
-        for try_count in range(1, max_tries + 1):
-            port += int(try_count**0.5)
+        # Bind port and try with higher ports if not available
+        port_start = port
+        for ind_try in range(max_tries):
             try:
                 s.bind((hostname, port))
                 break
@@ -168,11 +163,11 @@ class TcpConnection(Connection):
                 # just one port. Otherwise just try the next
                 if max_tries == 1:
                     raise
-                continue
+            port += int((ind_try + 1)**0.5)
         else:
             # We tried all ports without success
-            tmp = "Could not bind to any of the %i %i ports tried."
-            raise IOError(tmp % (max_tries, port))
+            tmp = "Could not bind to any of the %i ports tried, starting with %i."
+            raise IOError(tmp % (max_tries, port_start))
 
         # Tell the socket it is a host. Backlog of at least 1 to avoid linux
         # kernel from detecting SYN flood and throttling the connection (#381)
@@ -197,8 +192,8 @@ class TcpConnection(Connection):
         s.setsockopt(socket.SOL_SOCKET, socket.SO_SNDBUF, SOCKET_BUFFERS_SIZE)
         s.setsockopt(socket.SOL_SOCKET, socket.SO_RCVBUF, SOCKET_BUFFERS_SIZE)
 
-        # Refuse rediculously low timeouts
-        if timeout <= 0.01:
+        # Refuse ridiculously low timeouts
+        if timeout < 0.01:
             timeout = 0.01
 
         # Try to connect
@@ -208,6 +203,7 @@ class TcpConnection(Connection):
             try:
                 s.connect((hostname, port))
                 ok = True
+                break
             except socket.error:
                 pass
             except socket.timeout:
@@ -296,8 +292,11 @@ class HostThread(threading.Thread):
         self._context_connection = context_connection
         self._bsd_host_socket = bsd_socket
 
-        # Make deamon
-        self.setDaemon(True)
+        # Make daemon
+        if sys.version_info < (2, 6):
+            self.setDaemon(True)
+        else:
+            self.daemon = True
 
     def run(self):
         """run()
@@ -314,7 +313,7 @@ class HostThread(threading.Thread):
             if not s:
                 continue
 
-            # Check if not closed in the mean time
+            # Check if not closed in the meantime
             if not self._context_connection.is_waiting:
                 break
 
@@ -344,7 +343,7 @@ class HostThread(threading.Thread):
         """_wait_for_connection()
 
         The thread will wait here until someone connects. When a
-        connections is made, the new socket is returned.
+        connection is made, the new socket is returned.
 
         """
 
@@ -409,8 +408,7 @@ class HandShaker:
         elif request.startswith("YOTON!"):
             # Get id
             try:
-                tmp = request[6:].split(".", 1)  # partition not in Python24
-                id2_str, pid2_str = tmp[0], tmp[1]
+                id2_str, pid2_str = request[6:].split(".", 1)  # partition not in Python24
                 id2, pid2 = int(id2_str, 16), int(pid2_str, 10)
             except Exception:
                 self._send_during_handshaking("ERROR: could not parse id.")
@@ -437,7 +435,7 @@ class HandShaker:
 
         """
 
-        # Make our message with id and pif
+        # Make our message with id and pid
         message = "YOTON!%s.%i" % (UID(id).get_hex(), os.getpid())
 
         # Do request
@@ -452,8 +450,7 @@ class HandShaker:
         elif response.startswith("YOTON!"):
             # Get id
             try:
-                tmp = response[6:].split(".", 1)  # Partition not in Python24
-                id2_str, pid2_str = tmp[0], tmp[1]
+                id2_str, pid2_str = response[6:].split(".", 1)  # Partition not in Python24
                 id2, pid2 = int(id2_str, 16), int(pid2_str, 10)
             except Exception:
                 return False, STOP_HANDSHAKE_FAILED
@@ -480,7 +477,10 @@ class BaseIOThread(threading.Thread):
         threading.Thread.__init__(self)
 
         # Thread will "destruct" when the interpreter shuts down
-        self.setDaemon(True)
+        if sys.version_info < (2, 6):
+            self.setDaemon(True)
+        else:
+            self.daemon = True
 
         # Store (temporarily) the ref to the context connection
         # Also of bsd_socket, because it might be removed before the
@@ -550,7 +550,7 @@ class BaseIOThread(threading.Thread):
 class SendingThread(BaseIOThread):
     """The thread that reads packages from the queue and sends them over
     the socket. It uses a timeout while reading from the queue, so it can
-    send heart beat packages if no packages are send.
+    send heart beat packages if no packages are sent.
     """
 
     def _run(self, context_connection, bsd_socket):
@@ -663,7 +663,7 @@ class ReceivingThread(BaseIOThread):
 
         if size == 0:
             # A special package! (or someone sending a
-            # package with no content, which is discarted)
+            # package with no content, which is discarded)
             if package._source_seq == 0:
                 pass  # Heart beat
             elif package._source_seq == 1:
@@ -699,4 +699,4 @@ class ReceivingThread(BaseIOThread):
             n -= len(data)
 
         # Return combined data of multiple rounds
-        return bytes().join(parts)
+        return b"".join(parts)
