@@ -28,7 +28,7 @@ class Context(object):
     """Context(verbose=0, queue_params=None)
 
     A context represents a node in the network. It can connect to
-    multiple other contexts (using a yoton.Connection.
+    multiple other contexts (using a yoton.Connection).
     These other contexts can be in
     another process on the same machine, or on another machine
     connected via a network or the internet.
@@ -41,9 +41,9 @@ class Context(object):
     the packages are distributed to the right channels. A context queues
     packages while it is not connected to any other context.
 
-    If messages are send on a channel registered at this context while
+    If messages are sent on a channel registered at this context while
     the context is not connected, the messages are stored by the
-    context and will be send to the first connecting context.
+    context and will be sent to the first connecting context.
 
     Example 1
     ---------
@@ -70,12 +70,11 @@ class Context(object):
     for every context in the network. The value of queue_params should
     be a 2-element tuple specifying queue size and discard mode. The
     latter can be 'old' (default) or 'new', meaning that if the queue
-    is full, either the oldest or newest messages are discarted.
+    is full, either the oldest or newest messages are discarded.
 
     """
 
     def __init__(self, verbose=0, queue_params=None):
-
         # Whether or not to write status information
         self._verbose = verbose
 
@@ -113,9 +112,9 @@ class Context(object):
         and all channels.
 
         Closing a connection means disconnecting two contexts. Closing
-        a channel means disasociating a channel from its context.
+        a channel means disassociating a channel from its context.
         Unlike connections and channels, a Context instance can be reused
-        after closing (although this might not always the best strategy).
+        after closing (although this might not always be the best strategy).
 
         """
 
@@ -135,8 +134,8 @@ class Context(object):
         """
 
         # Get all channels
-        channels1 = [c for c in self._sending_channels.values()]
-        channels2 = [c for c in self._receiving_channels.values()]
+        channels1 = list(self._sending_channels.values())
+        channels2 = list(self._receiving_channels.values())
 
         # Close all channels
         for c in set(channels1 + channels2):
@@ -154,24 +153,18 @@ class Context(object):
         """
 
         # Lock
-        self._connections_lock.acquire()
-        try:
+        with self._connections_lock:
             return [c for c in self._connections if c.is_alive]
-        finally:
-            self._connections_lock.release()
 
     @property
     def connections(self):
         """Get a list of the Connection instances currently
         active for this context.
         In addition to normal list indexing, the connections objects can be
-        queried  from this list using their name.
+        queried from this list using their name.
         """
         # Lock
-        self._connections_lock.acquire()
-
-        try:
-
+        with self._connections_lock:
             # Clean up any dead connections
             copy = ConnectionCollection()
             to_remove = []
@@ -188,9 +181,6 @@ class Context(object):
             # Return copy
             return copy
 
-        finally:
-            self._connections_lock.release()
-
     @property
     def connection_count(self):
         """Get the number of connected contexts. Can be used as a boolean
@@ -210,7 +200,7 @@ class Context(object):
 
         Setup a connection with another Context, by being the host.
         This method starts a thread that waits for incoming connections.
-        Error messages are printed when an attemped connect fails. the
+        Error messages are printed when an attempted connect fails. the
         thread keeps trying until a successful connection is made, or until
         the connection is closed.
 
@@ -238,7 +228,7 @@ class Context(object):
         -----------------
         The hostname can be:
           * The IP address, or the string hostname of this computer.
-          * 'localhost': the connections is only visible from this computer.
+          * 'localhost': the connection is only visible from this computer.
             Also some low level networking layers are bypassed, which results
             in a faster connection. The other context should also connect to
             'localhost'.
@@ -264,15 +254,12 @@ class Context(object):
         connection._bind(hostname, port, max_tries)
 
         # Save connection instance
-        self._connections_lock.acquire()
-        try:
+        with self._connections_lock:
             # Push packages from startup queue
             while len(self._startupQueue):
                 connection._inject_package(self._startupQueue.pop())
             # Add connection object to list of connections
             self._connections.append(connection)
-        finally:
-            self._connections_lock.release()
 
         # Return Connection instance
         return connection
@@ -334,15 +321,12 @@ class Context(object):
         connection._connect(hostname, port, timeout)
 
         # Save connection instance
-        self._connections_lock.acquire()
-        try:
+        with self._connections_lock:
             # Push packages from startup queue
             while self._startupQueue:
                 connection._inject_package(self._startupQueue.pop())
             # Add connection object to list of connections
             self._connections.append(connection)
-        finally:
-            self._connections_lock.release()
 
         # Send message in the network to signal a new connection
         bb = "NEW_CONNECTION".encode("utf-8")
@@ -355,7 +339,7 @@ class Context(object):
     def flush(self, timeout=5.0):
         """flush(timeout=5.0)
 
-        Wait until all pending messages are send. This will flush all
+        Wait until all pending messages are sent. This will flush all
         messages posted from the calling thread. However, it is not
         guaranteed that no new messages are posted from another thread.
 
@@ -409,7 +393,7 @@ class Context(object):
 
         """
         for D in [self._receiving_channels, self._sending_channels]:
-            for key in [key for key in D.keys()]:
+            for key in list(D.keys()):
                 if D[key] == channel:
                     D.pop(key)
 
@@ -419,8 +403,8 @@ class Context(object):
         """_send_package(package)
 
         Used by the channels to send a package into the network.
-        This method routes the package to all currentlt connected
-        connections. If there are none, the packages is queued at
+        This method routes the package to all currentlty connected
+        connections. If there are none, the package is queued at
         the context.
 
         """
@@ -430,8 +414,7 @@ class Context(object):
         package._source_seq = self._send_seq
 
         # Send to all connections, or queue if there are none
-        self._connections_lock.acquire()
-        try:
+        with self._connections_lock:
             ok = False
             for c in self._connections:
                 if c.is_alive:  # Waiting or connected
@@ -440,8 +423,6 @@ class Context(object):
             # Should we queue the package?
             if not ok:
                 self._startupQueue.push(package)
-        finally:
-            self._connections_lock.release()
 
     def _recv_package(self, package, connection):
         """_recv_package(package, connection)
@@ -481,20 +462,17 @@ class Context(object):
 
         # Send package to other context (over all alive connections)
         if send_further:
-            self._connections_lock.acquire()
-            try:
+            with self._connections_lock:
                 for c in self._connections:
                     if c is connection or not c.is_alive:
                         continue
                     c._send_package(package)
-            finally:
-                self._connections_lock.release()
 
         # Process package here or pass to channel
         if deposit_here:
             if slot == SLOT_CONTEXT:
                 # Context-to-context messaging;
-                # A slot starting with a space reprsents the context
+                # A slot starting with a space represents the context
                 self._recv_context_package(package)
             else:
                 # Give package to a channel (if applicable)
@@ -516,13 +494,10 @@ class Context(object):
         if message == "CLOSE_CONNECTION":
             # Close the connection. Check which one of our connections is
             # connected with the context that send this message.
-            self._connections_lock.acquire()
-            try:
+            with self._connections_lock:
                 for c in self.connections:
                     if c.is_connected and c.id2 == package._source_id:
                         c.close(connection.STOP_CLOSED_FROM_THERE, False)
-            finally:
-                self._connections_lock.release()
 
         elif message == "NEW_CONNECTION":
             # Resend all status channels
